@@ -191,10 +191,10 @@ class DataFrameRegressionFixture:
     def check(
         self,
         data_frame: Any,
-        basename: Optional[str] = None,
+        basename: str | None = None,
         fullpath: Optional["os.PathLike[str]"] = None,
-        tolerances: Optional[dict[str, dict[str, float]]] = None,
-        default_tolerance: Optional[dict[str, float]] = None,
+        tolerances: dict[str, dict[str, float]] | None = None,
+        default_tolerance: dict[str, float] | None = None,
     ) -> None:
         """
         Checks a pandas dataframe, containing only numeric data, against a previously recorded version, or generate a new file.
